@@ -61,7 +61,7 @@ define("cors", default=None, type=dict, help="跨域策略")
 define("url_log_enable", default=False, type=bool, help="项目url打印")
 define("cronjob_config", default={}, type=dict, help="定时任务配置")
 define("resource_register_enable", default=False, type=bool, help="资源注册开关")
-define("options.outside_screen_port", default=80, type=int, help="资源注册开关")
+define("outside_screen_port", default=80, type=int, help="资源注册开关")
 # 日志初始化配置，配置文件中可修改设置
 options.logging = "DEBUG"
 options.log_rotate_mode = "time"
